==> infra-5.8.0-sources.jar: com/liveperson/infra/managers/PreferenceManager.java <==
package com.liveperson.infra.managers;

import android.content.Context;
import android.content.SharedPreferences;

import com.liveperson.infra.Infra;
import com.liveperson.infra.log.LPLog;

import java.util.Set;

/**
 * Created by Ilya Gazman on 11/5/2015.
 * <p/>
 * A utility class that wraps Android SharedPreferences
 */
public class PreferenceManager {

    private static final String TAG = "PreferenceManager";
    private static final String LP_SHARED_FILENAME = "lp_shared";
    public static final String APP_LEVEL_PREFERENCES = "appLevelPreferences";

    // Sdk version change preference key
    public static final String SDK_VERSION_CHANGED_CLEAR_DATABASE_KEY = "SDK_VERSION_CHANGED_CLEAR_DATABASE_KEY";

    // Photo sharing enabled preference key
    public static final String KILL_SWITCH_PHOTO_SHARING_ENABLED_PREFERENCE_KEY = "kill_switch_photo_sharing_enabled_preference_key";
    public static final String SITE_SETTINGS_PHOTO_SHARING_ENABLED_PREFERENCE_KEY = "site_settings_photo_sharing_enabled_preference_key";
    public static final String SITE_SETTINGS_VOICE_SHARING_ENABLED_PREFERENCE_KEY = "site_settings_voice_sharing_enabled_preference_key";
    public static final String SITE_SETTINGS_SDK_ANALYTICS_ENABLED_PREFERENCE_KEY = "site_settings_sdk_analytics_enabled_preference_key";
    public static final String SITE_SETTINGS_EVENT_MANAGER_DOMAIN_PREFERENCE_KEY = "site_settings_event_manager_domain_preference_key";
    public static final String ENABLE_TRANSCENDENT_MESSAGES_PREFERENCE_KEY = "enable_transcendent_messages_preference_key";

    // date when last configuration was sent preference key
    public static final String CONFIGURATION_DATA_PUBLISH_DATE_PREFERENCE_KEY = "configuration_data_publish_date_preference_key";

    public static final String IS_PUSHER_REGISTERED_PREFERENCE_KEY = "IS_PUSHER_REGISTERED_PREFERENCE_KEY";
    public static final String APP_ID_PREFERENCE_KEY = "APP_ID_PREFERENCE_KEY";
    public static final String PUSHER_DEVICE_TOKEN_PREFERENCE_KEY = "PUSHER_DEVICE_TOKEN_PREFERENCE_KEY";
    /** The consumer who is pending to unregister pusher, set old consumerId as the value.  */
    public static final String CONSUMER_UNREGISTER_PUSHER_PREFERENCE_KEY = "CONSUMER_UNREGISTER_PUSHER_PREFERENCE_KEY";
    public static final String KEY_TYPED_TEXT = "KEY_TYPED_TEXT";

    private static volatile SharedPreferences mPreferences;


    private static volatile PreferenceManager Instance = null;


    private PreferenceManager() {
        Context applicationContext = Infra.instance.getApplicationContext();
        mPreferences = applicationContext.getSharedPreferences(LP_SHARED_FILENAME, Context.MODE_PRIVATE);
    }


    /**
     * Get instance of the infra Preference Manager
     * Note: this class uses the application context initialized in the {@link Infra} class
     */
    public static PreferenceManager getInstance() {
        if (Instance == null) {
            synchronized (PreferenceManager.class) {
                if (Instance == null) {
                    Instance = new PreferenceManager();
                }
            }
        }
        return Instance;
    }


    /**
     * Setting long value to the SDK SharedPreferences
     */
    public void setLongValue(String key, String brandId, long value) {
        mPreferences.edit().putLong(buildKey(key, brandId), value).apply();
    }


    /**
     * Getting long value from the SDK SharedPreferences
     */
    public long getLongValue(String key, String brandId, long defValue) {
        return mPreferences.getLong(buildKey(key, brandId), defValue);
    }

    public void setBooleanValue(String key, String brandId, boolean value) {
        mPreferences.edit().putBoolean(buildKey(key, brandId), value).apply();
    }

    public boolean getBooleanValue(String key, String brandId, boolean defValue) {
        return mPreferences.getBoolean(buildKey(key, brandId), defValue);
    }

    public Set<String> getStringSet(String key, String brandId, Set<String> defValues) {
        return mPreferences.getStringSet(buildKey(key, brandId), defValues);
    }

    public void setIntValue(String key, String brandId, int value) {
        mPreferences.edit().putInt(buildKey(key, brandId), value).apply();
    }

    public int getIntValue(String key, String brandId, int defValue) {
        return mPreferences.getInt(buildKey(key, brandId), defValue);
    }

    public String getStringValue(String key, String brandId, String defValue) {
        return mPreferences.getString(buildKey(key, brandId), defValue);
    }

    public void setStringValue(String key, String brandId, String value) {
        mPreferences.edit().putString(buildKey(key, brandId), value).apply();
    }

    public void setStringsSet(String key, String brandId, Set<String> value) {
        mPreferences.edit().putStringSet(buildKey(key, brandId), value).apply();
    }

    public void remove(String key, String brandId) {
        mPreferences.edit().remove(buildKey(key, brandId)).apply();
    }

    public boolean contains(String key, String brandId) {
        return mPreferences.contains(buildKey(key, brandId));
    }

    public void clearAll() {
	    LPLog.INSTANCE.d(TAG, "Clearing all data");
        mPreferences.edit().clear().apply();
    }


    private String buildKey(String key, String brandId) {
        return key + "$$" + brandId;
    }
}

==> infra-5.11.0-sources.jar: com/liveperson/infra/managers/PreferenceManager.java <==
package com.liveperson.infra.managers;

import android.content.Context;
import android.content.SharedPreferences;

import com.liveperson.infra.Infra;
import com.liveperson.infra.log.LPLog;

import java.util.Set;

/**
 * Created by Ilya Gazman on 11/5/2015.
 * <p/>
 * A utility class that wraps Android SharedPreferences
 */
public class PreferenceManager {

    private static final String TAG = "PreferenceManager";
    private static final String LP_SHARED_FILENAME = "lp_shared";
    public static final String APP_LEVEL_PREFERENCES = "appLevelPreferences";

    // Sdk version change preference key
    public static final String SDK_VERSION_CHANGED_CLEAR_DATABASE_KEY = "SDK_VERSION_CHANGED_CLEAR_DATABASE_KEY";
    // SDK version
    public static final String SDK_VERSION_PREFERENCE_KEY = "SDK_VERSION_PREFERENCE_KEY";
    // Flag to know when sdk version changed then need to reset DBEncyptionService or not
    public static final String RESET_DB_ENCRYPTION_SERVICE_KEY = "RESET_DB_ENCRYPTION_SERVICE_KEY";

    // Photo sharing enabled preference key
    public static final String KILL_SWITCH_PHOTO_SHARING_ENABLED_PREFERENCE_KEY = "kill_switch_photo_sharing_enabled_preference_key";
    public static final String SITE_SETTINGS_PHOTO_SHARING_ENABLED_PREFERENCE_KEY = "site_settings_photo_sharing_enabled_preference_key";
    public static final String SITE_SETTINGS_VOICE_SHARING_ENABLED_PREFERENCE_KEY = "site_settings_voice_sharing_enabled_preference_key";
    public static final String SITE_SETTINGS_SDK_ANALYTICS_ENABLED_PREFERENCE_KEY = "site_settings_sdk_analytics_enabled_preference_key";
    public static final String SITE_SETTINGS_EVENT_MANAGER_DOMAIN_PREFERENCE_KEY = "site_settings_event_manager_domain_preference_key";
    public static final String ENABLE_TRANSCENDENT_MESSAGES_PREFERENCE_KEY = "enable_transcendent_messages_preference_key";

    // date when last configuration was sent preference key
    public static final String CONFIGURATION_DATA_PUBLISH_DATE_PREFERENCE_KEY = "configuration_data_publish_date_preference_key";

    public static final String IS_PUSHER_REGISTERED_PREFERENCE_KEY = "IS_PUSHER_REGISTERED_PREFERENCE_KEY";
    public static final String APP_ID_PREFERENCE_KEY = "APP_ID_PREFERENCE_KEY";
    public static final String PUSHER_DEVICE_TOKEN_PREFERENCE_KEY = "PUSHER_DEVICE_TOKEN_PREFERENCE_KEY";
    /** The consumer who is pending to unregister pusher, set old consumerId as the value.  */
    public static final String CONSUMER_UNREGISTER_PUSHER_PREFERENCE_KEY = "CONSUMER_UNREGISTER_PUSHER_PREFERENCE_KEY";
    public static final String KEY_TYPED_TEXT = "KEY_TYPED_TEXT";
    public static final String KEY_LATEST_OPEN_CONVERSATION_ID = "latest_open_conversation_id";
    public static final String KEY_STEP_UP_CONNECTOR_ID = "step_up_connector_id";

    private static volatile SharedPreferences mPreferences;


    private static volatile PreferenceManager Instance = null;


    private PreferenceManager() {
        Context applicationContext = Infra.instance.getApplicationContext();
        mPreferences = applicationContext.getSharedPreferences(LP_SHARED_FILENAME, Context.MODE_PRIVATE);
    }


    /**
     * Get instance of the infra Preference Manager
     * Note: this class uses the application context initialized in the {@link Infra} class
     */
    public static PreferenceManager getInstance() {
        if (Instance == null) {
            synchronized (PreferenceManager.class) {
                if (Instance == null) {
                    Instance = new PreferenceManager();
                }
            }
        }
        return Instance;
    }


    /**
     * Setting long value to the SDK SharedPreferences
     */
    public void setLongValue(String key, String brandId, long value) {
        mPreferences.edit().putLong(buildKey(key, brandId), value).apply();
    }


    /**
     * Getting long value from the SDK SharedPreferences
     */
    public long getLongValue(String key, String brandId, long defValue) {
        return mPreferences.getLong(buildKey(key, brandId), defValue);
    }

    public void setBooleanValue(String key, String brandId, boolean value) {
        mPreferences.edit().putBoolean(buildKey(key, brandId), value).apply();
    }

    public boolean getBooleanValue(String key, String brandId, boolean defValue) {
        return mPreferences.getBoolean(buildKey(key, brandId), defValue);
    }

    public Set<String> getStringSet(String key, String brandId, Set<String> defValues) {
        return mPreferences.getStringSet(buildKey(key, brandId), defValues);
    }

    public void setIntValue(String key, String brandId, int value) {
        mPreferences.edit().putInt(buildKey(key, brandId), value).apply();
    }

    public int getIntValue(String key, String brandId, int defValue) {
        return mPreferences.getInt(buildKey(key, brandId), defValue);
    }

    public String getStringValue(String key, String brandId, String defValue) {
        return mPreferences.getString(buildKey(key, brandId), defValue);
    }

    public void setStringValue(String key, String brandId, String value) {
        mPreferences.edit().putString(buildKey(key, brandId), value).apply();
    }

    public void setStringsSet(String key, String brandId, Set<String> value) {
        mPreferences.edit().putStringSet(buildKey(key, brandId), value).apply();
    }

    public void remove(String key, String brandId) {
        mPreferences.edit().remove(buildKey(key, brandId)).apply();
    }

    public boolean contains(String key, String brandId) {
        return mPreferences.contains(buildKey(key, brandId));
    }

    public void clearAll() {
	    LPLog.INSTANCE.d(TAG, "Clearing all data");
        mPreferences.edit().clear().apply();
    }


    private String buildKey(String key, String brandId) {
        return key + "$$" + brandId;
    }
}
